[−][src]Macro futures_util::poll
macro_rules! poll { ($x:expr $(,)?) => { ... }; }
A macro which returns the result of polling a future once within the
current async context.
This macro is only usable inside of async functions, closures, and blocks.
It is also gated behind the async-await feature of this library, which is
activated by default.